@@ -132,9 +132,9 @@ featureSignifGUI <- function(x, scaleData=FALSE)
     return()
   }
   
-  ######################################################################################################
+  ############################################################################
   ## GUI
-  #####################################################################################################
+  ############################################################################
 
   fs.env <- new.env()
     
@@ -145,6 +145,7 @@ featureSignifGUI <- function(x, scaleData=FALSE)
   heading.font <- tkfont.create(family="helvetica", weight="bold")
   space.font <- tkfont.create(size=10)
   textwidth <- 10
+  sf <- 4
   #space.label <- paste(rep(" ", scalebar.width), collapse="")
   tcl("tk_setPalette", "background", bg.col, "selectColor", "grey75") 
 
@@ -202,100 +203,96 @@ featureSignifGUI <- function(x, scaleData=FALSE)
   {  
     fspanel.width <- 740
     fspanel.height <- 410
-    ##fspanel.button.height <- 50
     fspanel.button.width <- (fspanel.width-40)/3
   }
   else
   {
     fspanel.width <- 950
     fspanel.height <- 410
-    ##fspanel.button.height <- 50
     fspanel.button.width <- (fspanel.width-50)/4
   }
   
   tt <- tktoplevel(width=fspanel.width, height=fspanel.height)
   tktitle(tt) <- paste("featureSignif GUI")
   tkgrid(tklabel(tt,text="featureSignif GUI: feature significance for multivariate kernel density estimation", font=heading.font, foreground=heading.col), row=1, columnspan=7+2*(d>=3))
-  tkgrid(tklabel(tt,text="", font=space.font), row=3, column=1)
-  tkgrid(tklabel(tt,text="", font=space.font), row=3, column=3)
-  tkgrid(tklabel(tt,text="", font=space.font), row=3, column=5)
-  tkgrid(tklabel(tt,text="", font=space.font), row=3, column=7)
-  if (d==3)
-  {
-    tkgrid(tklabel(tt,text="", font=space.font), row=3, column=7)
-    tkgrid(tklabel(tt,text="", font=space.font), row=3, column=9)
-    tkgrid(tklabel(tt,text=""), row=2, columnspan=11)
-    tkgrid(tklabel(tt,text=""), row=4, columnspan=11)
-    tkgrid(tklabel(tt,text=""), row=6, columnspan=11)  
-  }
-  else
-  {
-    tkgrid(tklabel(tt,text=""), row=2, columnspan=9)
-    tkgrid(tklabel(tt,text=""), row=4, columnspan=9)
-    tkgrid(tklabel(tt,text=""), row=6, columnspan=9)
-  }
-
+  tkgrid(tklabel(tt,text=" "), row=2, column=1)
+  tkgrid(tklabel(tt,text=" "), row=2, column=3)
+  tkgrid(tklabel(tt,text=" "), row=2, column=5)
+  tkgrid(tklabel(tt,text=" "), row=2, column=7)
+  if (d==3) tkgrid(tklabel(tt,text=" "), row=2, column=9)
+  tkgrid(tklabel(tt,text=" "), row=11, columnspan=7+2*(d>=3))
+  
   ## Bandwidths
   
   col1.frame <- tkframe(tt)
-  col1b.frame <- tkframe(col1.frame)
+  
   bw1.tcl <- tclVar(h[1])
   bw2.tcl <- tclVar(h[2])
   bw3.tcl <- tclVar(h[3])
 
   if (d>=1)
   {
-    bw1.s <- tkscale(col1.frame, from=h.low[1], to=h.upp[1], showvalue=TRUE, resolution=(h.upp[1]-h.low[1])/100, length=fspanel.button.width, variable=bw1.tcl, orient="horizontal", label=paste("Bandwidth for", names.x[1]))
+    col1b.frame <- tkframe(col1.frame)
+    bw1.s <- tkscale(col1b.frame, from=h.low[1], to=h.upp[1], showvalue=TRUE, resolution=(h.upp[1]-h.low[1])/100, length=fspanel.button.width, variable=bw1.tcl, orient="horizontal", label=paste("Bandwidth for", names.x[1]))
     tkconfigure(bw1.s, variable=bw1.tcl) 
     tkgrid(bw1.s, sticky="we")
+    tkgrid(col1b.frame)
+    tkgrid(tklabel(col1.frame, text=" "), sticky="w")
+    tkgrid(col1.frame, row=3, column=2, sticky="nw")
   }
   if (d>=2)
   {
+    col1b.frame <- tkframe(col1.frame)
     bw2.s <- tkscale(col1.frame, from=h.low[2], to=h.upp[2], showvalue=TRUE,  resolution=(h.upp[2]-h.low[2])/100, length=fspanel.button.width, variable=bw2.tcl, orient="horizontal", label=paste("Bandwidth for", names.x[2]))
     tkconfigure(bw2.s, variable=bw2.tcl) 
     tkgrid(bw2.s, sticky="we")
+    tkgrid(col1b.frame)
+    tkgrid(tklabel(col1.frame, text=" "), sticky="w")
+    tkgrid(col1.frame, row=5, column=2, sticky="nw")
   }
   if (d>=3)
   {
     bw3.s <- tkscale(col1.frame, from=h.low[3], to=h.upp[3], showvalue=TRUE,  resolution=(h.upp[3]-h.low[3])/100, length=fspanel.button.width, variable=bw3.tcl, orient="horizontal", label=paste("Bandwidth for", names.x[3]))
     tkconfigure(bw3.s, variable=bw3.tcl) 
     tkgrid(bw3.s, sticky="we")
+    tkgrid(col1b.frame)
+    tkgrid(col1.frame, row=7, column=2, sticky="we")
   }
-  tkgrid(col1b.frame, sticky="w")
   tkgrid(tklabel(col1.frame, text=" "), sticky="w")
   
   ## Grid size
 
   col1b.frame <- tkframe(col1.frame)
   gridsize.tcl <- tclVar(gridsize)
-  grid.e <- tkentry(col1b.frame, textvariable=gridsize.tcl, width=textwidth)
-  tkgrid(tklabel(col1b.frame, text="Grid size "), grid.e)
+  grid.e <- tkentry(col1b.frame, textvariable=gridsize.tcl, width=textwidth/2)
+  tkgrid(tklabel(col1b.frame, text="Grid size "), grid.e, sticky="nw")
   tkgrid(col1b.frame, sticky="w")
-  tkgrid(col1.frame, row=3, column=2, sticky="nw")
+  tkgrid(col1.frame, sticky="nw")
 
 
   ## Axis limits
   col2.frame <- tkframe(tt)
 
   if (d>=1)
-  {  
-    col2b.frame <- tkframe(col2.frame)
-    xlim1.tcl <- tclVar(xlim[1])
-    xlim1.e <- tkentry(col2b.frame, textvariable=xlim1.tcl, width=textwidth)
-    tkgrid(tklabel(col2b.frame, text="Axis lower limit "), xlim1.e)
-    tkgrid(col2b.frame, sticky="w")
-    
-    col2b.frame <- tkframe(col2.frame)
-    xlim2.tcl <- tclVar(xlim[2])
-    xlim2.e <- tkentry(col2b.frame, textvariable=xlim2.tcl, width=textwidth)
-    tkgrid(tklabel(col2b.frame, text="Axis upper limit "), xlim2.e)
-    tkgrid(col2b.frame, sticky="w")
-    
+  { 
     col2b.frame <- tkframe(col2.frame)
     xlab.tcl <- tclVar(names.x[1])
     xlab.e <- tkentry(col2b.frame, textvariable=xlab.tcl)
-    tkgrid(tklabel(col2b.frame, text="Axis label "), xlab.e)
+    tkgrid(tklabel(col2b.frame, text="Axis label", justify="left"), xlab.e, sticky="nw")
     tkgrid(col2b.frame, sticky="w")
+
+    col2b.frame <- tkframe(col2.frame)
+    xlim1.tcl <- tclVar(signif(xlim[1], digits=sf))
+    xlim1.e <- tkentry(col2b.frame, textvariable=xlim1.tcl, width=textwidth)
+    tkgrid(tklabel(col2b.frame, text="Axis lower limit ", justify="left"), xlim1.e, sticky="nw")
+    tkgrid(col2b.frame, sticky="w")
+    
+    col2b.frame <- tkframe(col2.frame)
+    xlim2.tcl <- tclVar(signif(xlim[2], digits=sf))
+    xlim2.e <- tkentry(col2b.frame, textvariable=xlim2.tcl, width=textwidth)
+    tkgrid(tklabel(col2b.frame, text="Axis upper limit", justify="left"), xlim2.e, sticky="nw")
+    tkgrid(col2b.frame, sticky="w")
+    
     tkgrid(tklabel(col2.frame, text=" "), sticky="w")
     tkgrid(col2.frame, row=3, column=4, sticky="ne")
     
@@ -303,68 +300,73 @@ featureSignifGUI <- function(x, scaleData=FALSE)
   if (d>=2)
   {  
     col2b.frame <- tkframe(col2.frame)
-    ylim1.tcl <- tclVar(ylim[1])
+    ylab.tcl <- tclVar(names.x[2])
+    ylab.e <- tkentry(col2b.frame, textvariable=ylab.tcl)
+    tkgrid(tklabel(col2b.frame, text="Axis label "), ylab.e)
+    tkgrid(col2b.frame, sticky="w")
+
+    col2b.frame <- tkframe(col2.frame)
+    ylim1.tcl <- tclVar(signif(ylim[1], digits=sf))
     ylim1.e <- tkentry(col2b.frame, textvariable=ylim1.tcl, width=textwidth)
     tkgrid(tklabel(col2b.frame, text="Axis lower limit "), ylim1.e)
     tkgrid(col2b.frame, sticky="w")
     
     col2b.frame <- tkframe(col2.frame)
-    ylim2.tcl <- tclVar(ylim[2])
+    ylim2.tcl <- tclVar(signif(ylim[2], digits=sf))
     ylim2.e <- tkentry(col2b.frame, textvariable=ylim2.tcl, width=textwidth)
-    tkgrid(tklabel(col2b.frame, text="Axis upper limit "), ylim2.e)
-    tkgrid(col2b.frame, sticky="w")
-    
-    col2b.frame <- tkframe(col2.frame)
-    ylab.tcl <- tclVar(names.x[2])
-    ylab.e <- tkentry(col2b.frame, textvariable=ylab.tcl)
-    tkgrid(tklabel(col2b.frame, text="Axis label "), ylab.e)
+    tkgrid(tklabel(col2b.frame, text="Axis upper limit"), ylim2.e)
     tkgrid(col2b.frame, sticky="w")
+   
     tkgrid(tklabel(col2.frame, text=" "), sticky="w")
+    tkgrid(col2.frame, row=5, column=4, sticky="ne")
   }
   if (d>=3)
   {  
-    col2b.frame <- tkframe(col2.frame)
-    zlim1.tcl <- tclVar(zlim[1])
-    zlim1.e <- tkentry(col2b.frame, textvariable=zlim1.tcl, width=textwidth)
-    tkgrid(tklabel(col2b.frame, text="Axis lower limit "), zlim1.e)
-    tkgrid(col2b.frame, sticky="w")
-    
-    col2b.frame <- tkframe(col2.frame)
-    zlim2.tcl <- tclVar(zlim[2])
-    zlim2.e <- tkentry(col2b.frame, textvariable=zlim2.tcl, width=textwidth)
-    tkgrid(tklabel(col2b.frame, text="Axis upper limit "), zlim2.e)
-    tkgrid(col2b.frame, sticky="w")
-    
     col2b.frame <- tkframe(col2.frame)
     zlab.tcl <- tclVar(names.x[3])
     zlab.e <- tkentry(col2b.frame, textvariable=zlab.tcl)
     tkgrid(tklabel(col2b.frame, text="Axis label "), zlab.e)
     tkgrid(col2b.frame, sticky="w")
+    
+    col2b.frame <- tkframe(col2.frame)
+    zlim1.tcl <- tclVar(signif(zlim[1], digits=sf))
+    zlim1.e <- tkentry(col2b.frame, textvariable=zlim1.tcl, width=textwidth)
+    tkgrid(tklabel(col2b.frame, text="Axis lower limit "), zlim1.e)
+    tkgrid(col2b.frame, sticky="w")
+    
+    col2b.frame <- tkframe(col2.frame)
+    zlim2.tcl <- tclVar(signif(zlim[2], digits=sf))
+    zlim2.e <- tkentry(col2b.frame, textvariable=zlim2.tcl, width=textwidth)
+    tkgrid(tklabel(col2b.frame, text="Axis upper limit"), zlim2.e)
+    tkgrid(col2b.frame, sticky="w")
+    tkgrid(col2.frame, row=7, column=4, sticky="w")
     tkgrid(tklabel(col2.frame, text=" "), sticky="w")
   }
   
   col2b.frame <- tkframe(col2.frame)
   addDataNum.tcl <- tclVar(1000)
-  addDataNum.e <- tkentry(col2b.frame, textvariable=addDataNum.tcl, width=textwidth)
+  addDataNum.e <- tkentry(col2b.frame, textvariable=addDataNum.tcl, width=textwidth/2)
   tkgrid(tklabel(col2b.frame, text="No. of display data points "), addDataNum.e)
   tkgrid(col2b.frame, sticky="w")
-  tkgrid(col2.frame, row=3, column=4, sticky="nw")
+  tkgrid(col2.frame,  sticky="nw")
 
   ## Plot options
   
   col3.frame <- tkframe(tt)
-  fsdata.b <- tkbutton(col3.frame, text="Add data\npoints", command=fsdata.tcl, background=button.col)
-  fsgradregion.b <- tkbutton(col3.frame, text="Add significant\ngradient region", command=fsgradregion.tcl, background=button.col)
-  fsgraddata.b <- tkbutton(col3.frame, text="Add significant\ngradient data", command=fsgraddata.tcl, background=button.col)
-  fscurvregion.b <- tkbutton(col3.frame, text="Add significant\ncurvature region", command=fscurvregion.tcl, background=button.col)
-  fscurvdata.b <- tkbutton(col3.frame, text="Add significant\ncurvature data", command=fscurvdata.tcl, background=button.col)
-  tkgrid(fsdata.b)
-  tkgrid(fsgradregion.b)
-  tkgrid(fsgraddata.b)
-  tkgrid(fscurvregion.b)
-  tkgrid(fscurvdata.b)
-  if (d==3) tkgrid(col3.frame, row=3, column=8, sticky="nw")
-  else tkgrid(col3.frame, row=3, column=6, sticky="nw")
+  col3b.frame <- tkframe(col3.frame)
+  fsdata.b <- tkbutton(col3b.frame, text=" ", command=fsdata.tcl, background=button.col)
+  fsgradregion.b <- tkbutton(col3b.frame, text=" ", command=fsgradregion.tcl, background=button.col)
+  fsgraddata.b <- tkbutton(col3b.frame, text=" ", command=fsgraddata.tcl, background=button.col)
+  fscurvregion.b <- tkbutton(col3b.frame, text=" ", command=fscurvregion.tcl, background=button.col)
+  fscurvdata.b <- tkbutton(col3b.frame, text=" ", command=fscurvdata.tcl, background=button.col)
+  tkgrid(fsdata.b, tklabel(col3b.frame, text="Add data\npoints", justify="left"), sticky="nw")
+  tkgrid(fsgradregion.b, tklabel(col3b.frame, text="Add significant\ngradient region", justify="left"), sticky="nw")
+  tkgrid(fsgraddata.b, tklabel(col3b.frame, text="Add significant\ngradient data", justify="left"), sticky="nw")
+  tkgrid(fscurvregion.b, tklabel(col3b.frame, text="Add significant\ncurvature region", justify="left"), sticky="nw")
+  tkgrid(fscurvdata.b, tklabel(col3b.frame, text="Add significant\ncurvature data", justify="left"), sticky="nw")
+  tkgrid(col3b.frame)
+  if (d==3) tkgrid(col3.frame, row=2*d+1, column=8, sticky="nw")
+  else tkgrid(col3.frame, row=2*d+1, column=6, sticky="nw")
 
   ## Transparency options
 
@@ -402,35 +404,35 @@ featureSignifGUI <- function(x, scaleData=FALSE)
     addAxes3d.cb <- tkcheckbutton(col4b.frame, variable=addAxes3d.tcl)
     tkgrid(addAxes3d.cb, tklabel(col4b.frame, text="Add 3D axes "))
     tkgrid(col4b.frame, sticky="nw")
-    tkgrid(col4.frame, row=3, column=6, sticky="nw")
+    tkgrid(col4.frame, row=7, column=6, sticky="nw")
   }
 
   ## Computation buttons
   
   col1.frame <- tkframe(tt)
-  fscreate.b <- tkbutton(col1.frame, text="Compute significant\nfeatures", command=fscreate.tcl, background=button.col)
-  tkgrid(fscreate.b)
-  tkgrid(col1.frame, row=5, column=2, sticky="n")
+  fscreate.b <- tkbutton(col1.frame, text=" ", command=fscreate.tcl, background=button.col)
+  tkgrid(fscreate.b, tklabel(col1.frame, text="Compute significant\nfeatures", justify="left"), sticky="nw")
+  tkgrid(col1.frame, row=9, column=2, sticky="nw")
 
   col2.frame <- tkframe(tt)
-  fsclearall1.b <- tkbutton(col2.frame, text="Reset plot\n(except KDE)", command=fsclearall1.tcl, background=button.col)
-  tkgrid(fsclearall1.b)
-  tkgrid(col2.frame, row=5, column=4, sticky="n")
+  fsclearall1.b <- tkbutton(col2.frame, text=" ", command=fsclearall1.tcl, background=button.col)
+  tkgrid(fsclearall1.b, tklabel(col2.frame, text="Reset plot (except KDE)", justify="left"), sticky="nw")
+  tkgrid(col2.frame, row=9, column=4, sticky="nw")
 
   col3.frame <- tkframe(tt)
   if (d==1)
   {
-    fssizer.b <- tkbutton(col3.frame, text="Compute SiZer map", command=fssizer.tcl, background=button.col)
-    fssicon.b <- tkbutton(col3.frame, text="Compute SiCon map", command=fssicon.tcl, background=button.col)
-    tkgrid(fssizer.b)
-    tkgrid(fssicon.b)
+    fssizer.b <- tkbutton(col3.frame, text=" ", command=fssizer.tcl, background=button.col)
+    fssicon.b <- tkbutton(col3.frame, text=" ", command=fssicon.tcl, background=button.col)
+    tkgrid(fssizer.b, tklabel(col3.frame, text="Compute SiZer map", justify="left"), sticky="nw")
+    tkgrid(fssicon.b, tklabel(col3.frame, text="Compute SiCon map", justify="left"), sticky="nw")
   }
   else
   {
-    fsclearall2.b <- tkbutton(col3.frame, text="Reset plot\n", command=fsclearall2.tcl, background=button.col)
-    tkgrid(fsclearall2.b)
+    fsclearall2.b <- tkbutton(col3.frame, text=" ", command=fsclearall2.tcl, background=button.col)
+    tkgrid(fsclearall2.b, tklabel(col3.frame, text="Reset plot", justify="left"), sticky="nw")
   }
-  tkgrid(col3.frame, row=5, column=6, sticky="n")
+  tkgrid(col3.frame, row=9, column=6, sticky="nw")
 }
 
 
